==> dl.php?src=linea21_1_6.zip: linea21/library/scripts/languages/da.js <==
{
    "ALLOWED_FILE_TYPE": "Only following files are allowed : ", 
    "AUTHORIZATION_REQUIRED": "Du har ikke adgang til at bruge fil manageren.", 
    "DIRECTORY_ALREADY_EXISTS": "Mappen '%s'  eksisterer allerede.", 
    "DIRECTORY_NOT_EXIST": "Mappen %s eksisterer ikke.", 
    "DISALLOWED_FILE_TYPE": "Following files are not allowed : ", 
    "ERROR_RENAMING_DIRECTORY": "Omdøbning af mappen %s til %s mislykkedes.", 
    "ERROR_RENAMING_FILE": "Omdøbning af filen %s til %s mislykkedes.", 
    "FILE_ALREADY_EXISTS": "The file '%s' already exists.", 
    "FILE_DOES_NOT_EXIST": "Filen %s eksisterer ikke.", 
    "INVALID_ACTION": "Invalid handling.", 
    "INVALID_DIRECTORY_OR_FILE": "Invalid mappe eller fil.", 
    "INVALID_FILE_TYPE": "File upload is not allowed.", 
    "INVALID_FILE_UPLOAD": "Invalid fil til upload: Har du valgt en fil?", 
    "INVALID_VAR": "Invalid variabel %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "Sprogfil ikke fundet.", 
    "MODE_ERROR": "Mode fejl.", 
    "UNABLE_TO_CREATE_DIRECTORY": "Ude af stand til at oprette mappen %s.", 
    "UNABLE_TO_OPEN_DIRECTORY": "Ude af stand til at åbne mappen %s.", 
    "UPLOAD_FILES_SMALLER_THAN": "Filen er for stor, filen skal være mindre end %s.", 
    "UPLOAD_IMAGES_ONLY": "Upload kun billeder, ingen andre filer er tilladte.", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "Kun billeder af typen JPEG, GIF eller PNG kan blive uploadet.", 
    "browse": "Browse...", 
    "bytes": " bytes", 
    "cancel": "Annullér", 
    "confirmation_delete": "Er du sikker på du ønsker at slette filen?", 
    "could_not_retrieve_folder": "Var ude af stand til at modtage mappens indhold.", 
    "create_folder": "Opret mappe", 
    "created": "Oprettet", 
    "current_folder": "Du er her: ", 
    "default_foldername": "Min mappe", 
    "del": "Slet", 
    "dimensions": "Dimensioner", 
    "download": "Hent", 
    "fck_select_integration": "Funktionen 'Vælg' er kun brugt ved brug af FCKEditor eller CKEditor.", 
    "file_size_limit": "The file size limit is : ", 
    "file_too_big": "The file is too big.", 
    "gb": "gb", 
    "grid_view": "Skift til gitter visning.", 
    "kb": "kb", 
    "list_view": "Skift til liste visning.", 
    "loading_data": "Transferring data ...", 
    "mb": "mb", 
    "modified": "Ændret", 
    "name": "Navn", 
    "new_filename": "Skriv et nyt navn for filen", 
    "new_folder": "Ny mappe", 
    "no": "Nej", 
    "no_foldername": "Ingen mappe var angivet.", 
    "parentfolder": "Hovedmappe", 
    "prompt_foldername": "Skriv navnet på den nye mappe", 
    "rename": "Omdøb", 
    "search": "Search", 
    "search_reset": "Reset", 
    "select": "Vælg", 
    "select_from_left": "Vælg et emne til venstre.", 
    "size": "Størrelse", 
    "successful_added_file": "Den nye fil blev tilføjet.", 
    "successful_added_folder": "Den nye mappe blev oprettet.", 
    "successful_delete": "Slettet med succes.", 
    "successful_rename": "Omdøbt med succes.", 
    "upload": "Upload", 
    "yes": "Ja"
}

==> dl.php?src=linea21_2_0_0.zip: linea21/library/scripts/languages/da.js <==
{
    "ALLOWED_FILE_TYPE": "Only following files are allowed : ", 
    "AUTHORIZATION_REQUIRED": "Du har ikke adgang til at bruge fil manageren.", 
    "DIRECTORY_ALREADY_EXISTS": "Mappen '%s'  eksisterer allerede.", 
    "DIRECTORY_NOT_EXIST": "Mappen %s eksisterer ikke.", 
    "DISALLOWED_FILE_TYPE": "Following files are not allowed : ", 
    "ERROR_CREATING_ZIP": "Error creating Zip archive", 
    "ERROR_OPENING_FILE": "Error opening file.", 
    "ERROR_RENAMING_DIRECTORY": "Omdøbning af mappen %s til %s mislykkedes.", 
    "ERROR_RENAMING_FILE": "Omdøbning af filen %s til %s mislykkedes.", 
    "ERROR_REPLACING_FILE": "Please, provide a file having the following extension :", 
    "ERROR_SAVING_FILE": "Error saving file.", 
    "ERROR_UPLOADING_FILE": "Error uploading file.", 
    "ERROR_WRITING_PERM": "You don't have write permissions on that file.", 
    "FILE_ALREADY_EXISTS": "The file '%s' already exists.", 
    "FILE_DOES_NOT_EXIST": "Filen %s eksisterer ikke.", 
    "INVALID_ACTION": "Invalid handling.", 
    "INVALID_DIRECTORY_OR_FILE": "Invalid mappe eller fil.", 
    "INVALID_FILE_TYPE": "File type is not allowed.", 
    "INVALID_FILE_UPLOAD": "Invalid fil til upload: Har du valgt en fil?", 
    "INVALID_VAR": "Invalid variabel %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "Sprogfil ikke fundet.", 
    "MODE_ERROR": "Mode fejl.", 
    "NOT_ALLOWED": "You are not allowed to process this action", 
    "NOT_ALLOWED_SYSTEM": "System permissions do not allow you to perform this action", 
    "UNABLE_TO_CREATE_DIRECTORY": "Ude af stand til at oprette mappen %s.", 
    "UNABLE_TO_OPEN_DIRECTORY": "Ude af stand til at åbne mappen %s.", 
    "UPLOAD_FILES_SMALLER_THAN": "Filen er for stor, filen skal være mindre end %s.", 
    "UPLOAD_IMAGES_ONLY": "Upload kun billeder, ingen andre filer er tilladte.", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "Kun billeder af typen JPEG, GIF eller PNG kan blive uploadet.", 
    "browse": "Browse...", 
    "bytes": " bytes", 
    "cancel": "Annullér", 
    "close": "Close", 
    "confirmation_delete": "Er du sikker på du ønsker at slette filen?", 
    "copied": "URL copied !", 
    "copy_to_clipboard": "Copy to Clipboard", 
    "could_not_retrieve_folder": "Var ude af stand til at modtage mappens indhold.", 
    "create_folder": "Opret mappe", 
    "created": "Oprettet", 
    "current_folder": "Du er her: ", 
    "default_foldername": "Min mappe", 
    "del": "Slet", 
    "dimensions": "Dimensioner", 
    "download": "Hent", 
    "dz_dictDefaultMessage": "Drop files here to upload", 
    "dz_dictFallbackMessage": "Your browser does not support drag'n'drop file uploads.", 
    "dz_dictInvalidFileType": "You can't upload files of this type.", 
    "dz_dictMaxFilesExceeded": "Only %s simultaneous uploads are allowed.", 
    "edit": "Edit file", 
    "fck_select_integration": "Funktionen 'Vælg' er kun brugt ved brug af FCKEditor eller CKEditor.", 
    "file_size_limit": "The file size limit is : ", 
    "file_too_big": "The file is too big.", 
    "gb": "gb", 
    "grid_view": "Skift til gitter visning.", 
    "help_move": "The use of '../' is forbidden. You can access root folder by using '/'.", 
    "items": "items", 
    "kb": "kb", 
    "list_view": "Skift til liste visning.", 
    "loading_data": "Transferring data ...", 
    "mb": "mb", 
    "modified": "Ændret", 
    "move": "Move to ...", 
    "name": "Navn", 
    "new_filename": "Skriv et nyt navn for filen", 
    "new_folder": "Ny mappe", 
    "no": "Nej", 
    "no_foldername": "Ingen mappe var angivet.", 
    "parentfolder": "Hovedmappe", 
    "prompt_foldername": "Skriv navnet på den nye mappe", 
    "quit_editor": "Quit editor", 
    "rename": "Omdøb", 
    "replace": "Replace file", 
    "save": "Save", 
    "search": "Search", 
    "search_reset": "Reset", 
    "select": "Vælg", 
    "select_from_left": "Vælg et emne til venstre.", 
    "size": "Størrelse", 
    "successful_added_file": "Den nye fil blev tilføjet.", 
    "successful_added_folder": "Den nye mappe blev oprettet.", 
    "successful_delete": "Slettet med succes.", 
    "successful_edit": "Content update successful.", 
    "successful_moved": "Move successful.", 
    "successful_rename": "Omdøbt med succes.", 
    "successful_replace": "File replacement successful.", 
    "support_fm": "Filemanager is a free software, please support !", 
    "upload": "Upload", 
    "version": "version", 
    "yes": "Ja"
}
